@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import
 import os.path as osp
-import logging, subprocess, os, time
+import logging, subprocess, os, time, sys
 from contextlib import contextmanager
 
 from . import path as seup
@@ -11,6 +11,9 @@ DEFAULT_LOGGING_LEVEL = logging.WARNING
 N_SECONDS_SLEEP = 10
 INCLUDE_DIR = osp.join(osp.abspath(osp.dirname(__file__)), "include")
 
+PY3 = sys.version_info.major == 3
+PY2 = sys.version_info.major == 2
+
 
 def version():
     with open(osp.join(INCLUDE_DIR, "VERSION"), "r") as f:
@@ -377,7 +380,7 @@ class NonZeroExitCode(subprocess.CalledProcessError):
 
 _valid_commands = [
     'mkdir', 'rm', 'stat', 'exists', 'isdir',
-    'isfile', 'is_file_or_dir', 'listdir', 'cp', 'cat'
+    'isfile', 'is_file_or_dir', 'listdir', 'cp', 'cat', 'cat_bytes'
     ]
 
 class Implementation:
@@ -403,7 +406,6 @@ class Implementation:
     def check_is_installed(self):
         raise NotImplementedError
 
-
     @add_env_kwarg
     def is_file_or_dir(self, path):
         """
@@ -507,6 +509,7 @@ isfile = make_global_scope_command('isfile')
 is_file_or_dir = make_global_scope_command('is_file_or_dir')
 listdir = make_global_scope_command('listdir')
 cat = make_global_scope_command('cat')
+cat_bytes = make_global_scope_command('cat_bytes')
 cp = make_global_scope_command('cp')
 stat_fn = stat # Alias for if stat is a keyword in a function in this module
 
@@ -760,6 +763,28 @@ def diff(left, right, stat=False, implementation=None):
         _sorted_paths_from_set(only_in_right, relpaths_right, contents_right),
         )
 
+
+def bytesio(path, implementation=None):
+    """
+    Simply calls cat_bytes, and returns that output in a BytesIO object.
+    Useful for loading npz or json from a filelike object.
+    """
+    from io import BytesIO
+    return BytesIO(cat_bytes(path, implementation=implementation))
+
+
+def load_npz(npz_file, *args, **kwargs):
+    """
+    Load an npz from a remote location.
+    """
+    implementation = kwargs.pop('implementation', None)
+    import numpy as np
+    if not seup.has_protocol(npz_file):
+        return np.load(npz_file, *args, **kwargs)
+    else:
+        return np.load(bytesio(npz_file, implementation=implementation), *args, **kwargs)
+
+
 # _______________________________________________________
 # CLI
 
